import request from '@/utils/request';
import { AxiosPromise } from 'axios';
import { SensorRetestVO, SensorRetestForm, SensorRetestQuery } from '@/api/qms/sensorRetest/types';

/**
 * 查询复测记录列表
 * @param query
 * @returns {*}
 */

export const listSensorRetest = (query?: SensorRetestQuery): AxiosPromise<SensorRetestVO[]> => {
  return request({
    url: '/qms/sensorRetest/list',
    method: 'get',
    params: query
  });
};

/**
 * 查询复测记录详细
 * @param batchCode
 */
export const getSensorRetest = (batchCode: string | number): AxiosPromise<SensorRetestVO> => {
  return request({
    url: '/qms/sensorRetest/' + batchCode,
    method: 'get'
  });
};

/**
 * 新增复测记录
 * @param data
 */
export const addSensorRetest = (data: SensorRetestForm) => {
  return request({
    url: '/qms/sensorRetest',
    method: 'post',
    data: data
  });
};

/**
 * 修改复测记录
 * @param data
 */
export const updateSensorRetest = (data: SensorRetestForm) => {
  return request({
    url: '/qms/sensorRetest',
    method: 'put',
    data: data
  });
};

/**
 * 删除复测记录
 * @param batchCode
 */
export const delSensorRetest = (batchCode: string | number | Array<string | number>) => {
  return request({
    url: '/qms/sensorRetest/' + batchCode,
    method: 'delete'
  });
};
